Module validators

Module validators 

Page/URL validators for form fields

This module provides validators for URL and URL slug validation that integrate with the form field validation pipeline.

Structs

SlugValidator
Validates that a string value is a valid URL slug.
UrlValidator
Validates that a string value is a well-formed HTTP or HTTPS URL.